@@ -19,7 +19,7 @@
  **/
 class SensorSensor : public Sensor
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     SensorSensor(int interval, char tempUnit);
@@ -34,7 +34,7 @@ private:
     TQString extraParams;
 
     TQMap<TQString,TQString> sensorMap;
-#ifdef __FreeBSD__
+#if defined __FreeBSD__ || defined(Q_OS_NETBSD)
     TQMap<TQString,TQString> sensorMapBSD;
 #endif
     TQString sensorResult;
